# Cryptolog

Cryptolog enhances user privacy by logging ephemeral identifiers in IPv6
notation instead of client IP addresses in Drupal's database tables and
syslog.

Once enabled in a site's settings.php file, Cryptolog replaces the PHP
global variable `$_SERVER['REMOTE_ADDR']` with a keyed hash of the client
IP address using a salt that is stored in memory and regenerated each
day.

Because Cryptolog uses the same unique identifier per IP address for a
24-hour period, it is still possible to do some statistical analysis of
the logs such as counting unique visitors per day.

Note: As long as the salt can still be retrieved, brute force can be
used to generate a rainbow table and reverse engineer the client IP
addresses. However, once the salt has expired and a new salt
regenerated, or the web server has been shutdown or restarted, it should
not be feasible to determine client IP addresses.


## Installation

Before installing Cryptolog, you must install either the Memcache Drupal
module, the APCu PHP extension, the APC PHP extension, or the XCache PHP
extension.

In addition, PHP must have been compiled with IPv6 support enabled.

Cryptolog will use the Sodium PHP extension, if available, to generate
keyed hashes, otherwise falling back to the Hash PHP extension.

To enable Cryptolog, add this line at the end of your site's
settings.php file (after Memcache or any other cache handlers):

```php
$conf['cache_backends'][] = 'sites/all/modules/contrib/cryptolog/cryptolog.inc';
```

If you have installed Cryptolog module somewhere other than
sites/all/modules/contrib then modify the file path accordingly.


## Credits

This module was inspired by the [Cryptolog log filter
script](https://github.com/EFForg/cryptolog).
